Index: src/control/audio.c
===================================================================
--- src/control/audio.c	(revision 22733)
+++ src/control/audio.c	(working copy)
@@ -115,6 +115,23 @@
 }
 
 /*****************************************************************************
+ * libvlc_audio_get_track_count : Get the number of available audio tracks
+ *****************************************************************************/
+int libvlc_audio_get_track_count( libvlc_media_instance_t *p_mi, 
+                                  libvlc_exception_t *p_e )
+{
+    input_thread_t *p_input_thread = libvlc_get_input_thread( p_mi, p_e );
+    vlc_value_t val_list;
+
+    if( !p_input_thread )
+        return -1;
+
+    var_Change( p_input_thread, "audio-es", VLC_VAR_GETCHOICES, &val_list, NULL );
+    vlc_object_release( p_input_thread );
+    return val_list.p_list->i_count;
+}
+
+/*****************************************************************************
  * libvlc_audio_get_track : Get the current audio track
  *****************************************************************************/
 int libvlc_audio_get_track( libvlc_media_instance_t *p_mi,
@@ -152,6 +169,7 @@
     return i_track;
 }
 
+
 /*****************************************************************************
  * libvlc_audio_set_track : Set the current audio track
  *****************************************************************************/
Index: src/control/media_descriptor.c
===================================================================
--- src/control/media_descriptor.c	(revision 22733)
+++ src/control/media_descriptor.c	(working copy)
@@ -262,6 +262,8 @@
     libvlc_event_manager_register_event_type( p_md->p_event_manager,
         libvlc_MediaDescriptorSubItemAdded, p_e );
     libvlc_event_manager_register_event_type( p_md->p_event_manager,
+        libvlc_MediaDescriptorFreed, p_e );
+    libvlc_event_manager_register_event_type( p_md->p_event_manager,
         libvlc_MediaDescriptorDurationChanged, p_e );
 
     vlc_gc_incref( p_md->p_input_item );
@@ -316,6 +318,14 @@
     uninstall_input_item_observer( p_md );
     vlc_gc_decref( p_md->p_input_item );
 
+    /* Construct the event */
+    libvlc_event_t event;
+    event.type = libvlc_MediaDescriptorFreed;
+    event.u.media_descriptor_freed.md = p_md;
+
+    /* Send the event */
+    libvlc_event_send( p_md->p_event_manager, &event );
+
     char ** all_keys = vlc_dictionary_all_keys( &p_md->tags );
     for( i = 0; all_keys[i]; i++ )
     {
Index: include/vlc/libvlc.h
===================================================================
--- include/vlc/libvlc.h	(revision 22733)
+++ include/vlc/libvlc.h	(working copy)
@@ -917,6 +917,14 @@
 VLC_PUBLIC_API void libvlc_audio_set_volume( libvlc_instance_t *, int, libvlc_exception_t *);
 
 /**
+ * Get number of available audio tracks
+ * \param p_mi media instance
+ * \param p_e an initialized exception
+ * \return the number of available audio tracks (int)
+ */
+VLC_PUBLIC_API int libvlc_audio_get_track_count( libvlc_media_instance_t *,  libvlc_exception_t * );
+
+/**
 +  * Get current audio track
 +  * \param p_input input instance
 +  * \param p_exception an initialized exception
Index: include/vlc/libvlc_structures.h
===================================================================
--- include/vlc/libvlc_structures.h	(revision 22733)
+++ include/vlc/libvlc_structures.h	(working copy)
@@ -298,6 +298,7 @@
     libvlc_MediaDescriptorSubItemAdded,
     libvlc_MediaDescriptorDurationChanged,
     libvlc_MediaDescriptorPreparsedChanged,
+    libvlc_MediaDescriptorFreed,
 
     libvlc_MediaInstancePlayed,
     libvlc_MediaInstancePaused,
@@ -343,6 +344,10 @@
         {
             int new_status;
         } media_descriptor_preparsed_changed;
+        struct
+        {
+            libvlc_media_descriptor_t * md;
+        } media_descriptor_freed;
             
         /* media instance */
         struct
